@@ -60,7 +60,7 @@
 ##' This allows for easy specification of the structure of the perturbations that are to be applied.
 ##' For example,
 ##' \preformatted{
-##'     rw.sd(a=0.05, b=ifelse(time==time[1],0.2,0),
+##'     rw_sd(a=0.05, b=ifelse(time==time[1],0.2,0),
 ##'           c=ivp(0.2), d=ifelse(time==time[13],0.2,0),
 ##'           e=ivp(0.2,lag=13), f=ifelse(time<23,0.02,0))
 ##' }
@@ -68,7 +68,7 @@
 ##' Parameters \code{d} and \code{e}, by contrast, get perturbations of s.d.  0.2 only just before the thirteenth observation.
 ##' Finally, parameter \code{f} gets a random perturbation of size 0.02 before every observation falling before \eqn{t=23}.
 ##'
-##' On the \eqn{m}-th IF2 iteration, prior to time-point \eqn{n}, the \eqn{d}-th parameter is given a random increment normally distributed with mean \eqn{0} and standard deviation \eqn{c_{m,n} \sigma_{d,n}}{c[m,n] sigma[d,n]}, where \eqn{c} is the cooling schedule and \eqn{\sigma}{sigma} is specified using \code{rw.sd}, as described above.
+##' On the \eqn{m}-th IF2 iteration, prior to time-point \eqn{n}, the \eqn{d}-th parameter is given a random increment normally distributed with mean \eqn{0} and standard deviation \eqn{c_{m,n} \sigma_{d,n}}{c[m,n] sigma[d,n]}, where \eqn{c} is the cooling schedule and \eqn{\sigma}{sigma} is specified using \code{rw_sd}, as described above.
 ##' Let \eqn{N} be the length of the time series and \eqn{\alpha=}{alpha=}\code{cooling.fraction.50}.
 ##' Then, when \code{cooling.type="geometric"}, we have \deqn{c_{m,n}=\alpha^{\frac{n-1+(m-1)N}{50N}}.}{c[m,n]=alpha^((n-1+(m-1)N)/(50N)).}
 ##' When \code{cooling.type="hyperbolic"}, we have \deqn{c_{m,n}=\frac{s+1}{s+n+(m-1)N},}{c[m,n]=(s+1)/(s+n+(m-1)N),} where \eqn{s} satisfies \deqn{\frac{s+1}{s+50N}=\alpha.}{(s+1)/(s+50N)=alpha.}
@@ -241,15 +241,20 @@ setMethod(
 
     ndone <- object@Nmif
 
-    obj <- mif2(object,Nmif=Nmif,...,
-      .ndone=ndone,.paramMatrix=object@paramMatrix)
+    obj <- mif2(
+      object,
+      Nmif=Nmif,
+      ...,
+      .ndone=ndone,
+      .paramMatrix=object@paramMatrix
+    )
 
     object@traces[ndone+1,"loglik"] <- obj@traces[1L,"loglik"]
     obj@traces <- rbind(
       object@traces,
       obj@traces[-1L,colnames(object@traces)]
     )
-    names(dimnames(obj@traces)) <- c("iteration","variable")
+    names(dimnames(obj@traces)) <- c("iteration","name")
     obj@Nmif <- as.integer(ndone+Nmif)
 
     obj
@@ -306,14 +311,19 @@ mif2_internal <- function (object, Nmif, rw.sd,
 
   if (is.null(.paramMatrix)) {
     paramMatrix <- array(data=start,dim=c(length(start),Np[1L]),
-      dimnames=list(variable=names(start),rep=NULL))
+      dimnames=list(name=names(start),rep=NULL))
   } else {
     paramMatrix <- .paramMatrix
   }
 
-  traces <- array(dim=c(Nmif+1,length(start)+1),
-    dimnames=list(iteration=seq.int(.ndone,.ndone+Nmif),
-      variable=c("loglik",names(start))))
+  traces <- array(
+    data=NA_real_,
+    dim=c(Nmif+1,length(start)+1),
+    dimnames=list(
+      iteration=NULL,
+      name=c("loglik",names(start))
+    )
+  )
   traces[1L,] <- c(NA,start)
 
   pompLoad(object,verbose=verbose)
@@ -489,7 +499,7 @@ perturbn_kernel_sd <- function (rw.sd, time, paramnames) {
     enclos <- rw.sd@envir
     rw.sd <- as.list(rw.sd@call)[-1L]
   } else {
-    pStop_(sQuote("rw.sd")," should be specified using the ",sQuote("rw.sd"),
+    pStop_(sQuote("rw.sd")," should be specified using the ",sQuote("rw_sd"),
       " function. See ",sQuote("?mif2"),".")
   }
   if (is.null(names(rw.sd)) | any(names(rw.sd)==""))
